==> mirrorsharp-codemirror-6-preview-0.0.9.tgz: package/main/codemirror/server/send-changes.js <==
import { ViewPlugin } from '@codemirror/next/view';

function sendReplace(connection, from, to, text, cursorOffset) {
  // eslint-disable-next-line @typescript-eslint/no-floating-promises
  connection.sendReplaceText(from, to - from, text.toString(), cursorOffset);
}

function sendChanges(connection, changes, prevCursorOffset, cursorOffset) {
  let changeCount = 0;
  let firstFrom;
  let firstTo;
  let firstText;
  changes.iterChanges((from, to, _f, _t, inserted) => {
    changeCount += 1;

    if (changeCount === 1) {
      firstFrom = from;
      firstTo = to;
      firstText = inserted;
      return;
    }

    if (changeCount === 2) {
      // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
      sendReplace(connection, firstFrom, firstTo, firstText, cursorOffset);
    }

    sendReplace(connection, from, to, inserted, cursorOffset);
  });

  if (changeCount === 1) {
    // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
    if (firstFrom === prevCursorOffset && firstTo === firstFrom && firstText.length === 1) {
      // eslint-disable-next-line @typescript-eslint/no-floating-promises, @typescript-eslint/no-non-null-assertion
      connection.sendTypeChar(firstText.line(1).slice(0, 1));
      return true;
    } // eslint-disable-next-line @typescript-eslint/no-non-null-assertion


    sendReplace(connection, firstFrom, firstTo, firstText, cursorOffset);
  }
}

export const sendChangesToServer = connection => ViewPlugin.define(view => {
  if (view.state.doc.length !== 0) sendReplace(connection, 0, 0, view.state.doc, view.state.selection.primary.from);
  return {
    update({
      docChanged,
      selectionSet,
      changes,
      state,
      prevState
    }) {
      const prevCursorOffset = prevState.selection.primary.from;
      const cursorOffset = state.selection.primary.from;

      if (docChanged) {
        sendChanges(connection, changes, prevCursorOffset, cursorOffset);
        return; // this will send selection move so we don't have to repeat
      }

      if (selectionSet) {
        // eslint-disable-next-line @typescript-eslint/no-floating-promises
        connection.sendMoveCursor(cursorOffset);
      }
    }

  };
});

==> mirrorsharp-codemirror-6-preview-0.13.0.tgz: package/main/codemirror/server/send-changes.js <==
import { ViewPlugin } from '@codemirror/view';

function sendReplace(connection, from, to, text, cursorOffset) {
  // eslint-disable-next-line @typescript-eslint/no-floating-promises
  connection.sendReplaceText(from, to - from, text.toString(), cursorOffset);
}

function sendChanges(connection, changes, prevCursorOffset, cursorOffset) {
  let changeCount = 0;
  let firstFrom;
  let firstTo;
  let firstText;
  changes.iterChanges((from, to, _f, _t, inserted) => {
    changeCount += 1;

    if (changeCount === 1) {
      firstFrom = from;
      firstTo = to;
      firstText = inserted;
      return;
    }

    if (changeCount === 2) {
      // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
      sendReplace(connection, firstFrom, firstTo, firstText, cursorOffset);
    }

    sendReplace(connection, from, to, inserted, cursorOffset);
  });

  if (changeCount === 1) {
    // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
    if (firstFrom === prevCursorOffset && firstTo === firstFrom && firstText.length === 1) {
      // eslint-disable-next-line @typescript-eslint/no-floating-promises, @typescript-eslint/no-non-null-assertion
      connection.sendTypeChar(firstText.line(1).text.charAt(0));
      return true;
    } // eslint-disable-next-line @typescript-eslint/no-non-null-assertion


    sendReplace(connection, firstFrom, firstTo, firstText, cursorOffset);
  }
}

export const sendChangesToServer = connection => ViewPlugin.define(view => {
  if (view.state.doc.length !== 0) sendReplace(connection, 0, 0, view.state.doc, view.state.selection.main.from);
  return {
    update({
      docChanged,
      selectionSet,
      changes,
      state,
      startState
    }) {
      const prevCursorOffset = startState.selection.main.from;
      const cursorOffset = state.selection.main.from;

      if (docChanged) {
        sendChanges(connection, changes, prevCursorOffset, cursorOffset);
        return; // this will send selection move so we don't have to repeat
      }

      if (selectionSet) {
        // eslint-disable-next-line @typescript-eslint/no-floating-promises
        connection.sendMoveCursor(cursorOffset);
      }
    }

  };
});
